@@ -15,6 +15,11 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *----------------------------------------------------------------------------
+ * Version 1.12
+ *   - Fix error in example
+ *   - Fix double free, which could result in broken images when image
+ *     splitting and palletized output were enabled.
+ *
  * Version 1.11
  *   - Add option to not split lines, if the rest isn't a minimum
  *     of 3 (default) frames long
@@ -302,8 +307,6 @@ void write_png(int file_id, uint8_t *image, int w, int h, int graphic, uint32_t
 	/* Free memory */
 	png_destroy_write_struct(&png_ptr, &info_ptr);
 	free(row_pointers);
-	if (pal != NULL)
-		free(pal);
 	if (palette != NULL)
 		free(palette);
 	if (trans != NULL)
@@ -618,7 +621,7 @@ void print_usage ()
 		"  -b, --buffer-opt <integer>   Optimize PG buffer size by image\n"
 		"                               splitting. [on=1, off=0]\n\n"
 		"Example:\n"
-		"  avs2bdnxml -t Undefined -l und -v 1080p -f 23.976 -a1 -81 -b0 -m3 \\\n"
+		"  avs2bdnxml -t Undefined -l und -v 1080p -f 23.976 -a1 -p1 -b0 -m3 \\\n"
 		"    -o output.xml input.avs\n"
 		"  (Input and output are required settings. The rest are set to default.)\n"
 		);
@@ -995,6 +998,11 @@ int main (int argc, char *argv[])
 			pal = palletize(out_buf, s_info->i_width, s_info->i_height);
 		for (j = 0; j < n_crop; j++)
 			write_png(start_frame, out_buf, s_info->i_width, s_info->i_height, j, pal, crops[j]);
+		if (pal_png)
+		{
+			free(pal);
+			pal = NULL;
+		}
 		num_of_events++;
 		if (first_frame == -1)
 			first_frame = i;
